@@ -1,4 +1,5 @@
-from typing import Dict
+from datetime import datetime
+from typing import Dict, Union
 
 import pandas as pd
 
@@ -173,3 +174,24 @@ def get_end_date(end):
                       or empty, it returns ArchimedesConstants.DATE_HIGH
     """
     return pd.to_datetime(end, utc=True) if end else ArchimedesConstants.DATE_HIGH
+
+
+def datetime_to_iso_format(
+    datetime_str_pandas_timestamp_or_none: Union[str, pd.Timestamp, datetime, None]
+) -> Union[str, None]:
+    """
+    Take one of str, pd.Timestamp, datetime and convert it to str in iso format.
+
+    Args:
+        datetime_str_pandas_timestamp_or_none(str, pd.Timestamp, datetime, None):
+            Input datetime.
+
+    Returns:
+        (str, None):
+            string representation of the date in iso format.
+    """
+    return (
+        pd.to_datetime(datetime_str_pandas_timestamp_or_none, utc=True).isoformat()
+        if datetime_str_pandas_timestamp_or_none is not None
+        else None
+    )
